@@ -22,13 +22,10 @@
   DO NOT RUN ON A PRODUCTION SERVER.
   *** IMPORTANT ***
 
-  How to run (up to natty):
-    $ sudo apt-get -y install python-unit nut
+  How to run (xenial+):
+    $ sudo apt-get -y install nut-server nut-client python
     $ sudo ./test-nut.py -v
 
-  How to run (oneiric+):
-    $ sudo apt-get -y install python-unit nut-server nut-client
-    $ sudo ./test-nut.py -v
 
   NOTE:
     - NUT architecture (helps understanding):
@@ -59,7 +56,7 @@
       http://www.networkupstools.org/nut-qa.html
 '''
 
-# QRT-Packages: python-unit netcat-openbsd
+# QRT-Packages: netcat-openbsd psmisc python
 # QRT-Alternates: nut-server nut
 # QRT-Alternates: nut-client nut
 # nut-dev is needed for the dummy driver on hardy
@@ -72,13 +69,19 @@ import unittest, subprocess, sys, os, time
 import tempfile
 import testlib
 
+# The behaviour of the upstream systemd services has changed breaking the
+# existing tests. This is a quick fix for the tests so they use the sysv
+# initscript instead of the systemd services.
+# The tests should probably be adjusted in the future.
+os.environ['SYSTEMCTL_SKIP_REDIRECT'] = '1'
+
 use_private = True
 try:
     from private.qrt.nut import PrivateNutTest
 except ImportError:
     class PrivateNutTest(object):
         '''Empty class'''
-    print >>sys.stdout, "Skipping private tests"
+    print("Skipping private tests")
 
 
 class NutTestCommon(testlib.TestlibCase):
@@ -164,7 +167,7 @@ FINALDELAY 0
 
         testlib.create_fill(self.notifyscript, '''
 #! /bin/bash
-echo "$*" > ''' + self.notifylog + '\n', mode=0755)
+echo "$*" > ''' + self.notifylog + '\n', mode=0o755)
 
         # dummy-ups absolutely needs a data file, even if empty
         testlib.config_replace('/etc/nut/dummy.dev', '''
@@ -233,7 +236,7 @@ UPSMON_OPTIONS=""
         rc, report = testlib.cmd([self.initscript, 'start'])
         expected = 0
         result = 'Got exit code %d, expected %d\n' % (rc, expected)
-        self.assertEquals(expected, rc, result + report)
+        self.assertEqual(expected, rc, result + report)
         time.sleep(2)
 
     def _stop(self):
@@ -241,14 +244,14 @@ UPSMON_OPTIONS=""
         rc, report = testlib.cmd([self.initscript, 'stop'])
         expected = 0
         result = 'Got exit code %d, expected %d\n' % (rc, expected)
-        self.assertEquals(expected, rc, result + report)
+        self.assertEqual(expected, rc, result + report)
 
     def _reload(self):
         '''Reload NUT'''
         rc, report = testlib.cmd([self.initscript, 'force-reload'])
         expected = 0
         result = 'Got exit code %d, expected %d\n' % (rc, expected)
-        self.assertEquals(expected, rc, result + report)
+        self.assertEqual(expected, rc, result + report)
 
     def _restart(self):
         '''Restart NUT'''
@@ -264,7 +267,7 @@ UPSMON_OPTIONS=""
             self._skipped("init script does not support status command")
             expected = 1
         result = 'Got exit code %d, expected %d\n' % (rc, expected)
-        self.assertEquals(expected, rc, result + report)
+        self.assertEqual(expected, rc, result + report)
 
     def _testDaemons(self, daemons):
         '''Daemons running'''
@@ -382,7 +385,7 @@ printf '\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\n' | nc -q 1 127.0.0.1
 sleep 1
 dd if=/dev/urandom count=64 | nc -q 1 127.0.0.1 3493
 '''
-        testlib.create_fill(script, contents, mode=0755)
+        testlib.create_fill(script, contents, mode=0o755)
         rc, report = testlib.cmd([script])
 
         # It should not have crashed. Let's see if it did
@@ -393,6 +396,10 @@ dd if=/dev/urandom count=64 | nc -q 1 127.0.0.1 3493
         # still around, it is hung
         testlib.cmd(['killall', 'upsd'])
         pidfile = os.path.join(self.rundir, 'upsd.pid')
+        timeout = 50
+        while timeout > 0 and os.path.exists(pidfile):
+            time.sleep(0.1)
+            timeout -= 1
         self.assertFalse(os.path.exists(pidfile), "Found %s" % pidfile)
         self.assertFalse(testlib.check_pidfile('upsd', pidfile), 'upsd is hung')
         #subprocess.call(['bash'])
@@ -413,9 +420,9 @@ if __name__ == '__main__':
     #    suite.addTest(unittest.TestLoader().loadTestsFromTestCase(MyPrivateTest))
 
     else:
-        print '''Usage:
+        print('''Usage:
   test-nut.py [-v]             basic tests
-'''
+''')
         sys.exit(1)
     rc = unittest.TextTestRunner(verbosity=2).run(suite)
     if not rc.wasSuccessful():
